# Houston

![PyPI](https://img.shields.io/pypi/v/houston-client)

Python Client for Houston (https://callhouston.io). 
Houston is an open source tool for building low cost, scalable, platform-agnostic data pipelines. 
Teams can share data processes as microservices using a simple API.


## Installation

This client can be installed via pip:

```bash
pip install houston-client
```

If you're running Houston on Google Cloud Platform you will need the 'gcp' plugin:

```bash
pip install "houston-client[gcp]"
```

## Usage

To get started in under 15 minutes, see the quickstart repo: https://github.com/datasparq-intelligent-products/houston-quickstart-python 

Full documentation is available at https://callhouston.io/docs


## Requirements

- Python >= 3.7
